/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.message.inbox;

import nl.cloudfarming.client.message.api.Message;
import nl.cloudfarming.client.message.api.MessageEvent;
import nl.cloudfarming.client.message.api.MessageEventKey;
import nl.cloudfarming.client.message.api.MessageEventListener;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.util.lookup.ServiceProvider;
import org.openide.util.lookup.ServiceProviders;

/**
 *
 * @author merijn
 */
@ServiceProviders(value = {
    @ServiceProvider(service = GuiEventListener.class)
})
public class MessageInboxController extends MessageEventListener {

    private MessageInboxPanel panel;

    public MessageInboxPanel getComponent() {
        if (panel == null) {
            panel = new MessageInboxPanel();
        }
        return panel;
    }

    public void addMessage(Message message) {
        getComponent().addMessage(message);
    }

    @Override
    public String getModuleName() {
        return MessageInboxModule.MODULE_NAME;
    }

    @Override
    public void onEvent(MessageEvent event) {
        if (MessageEventKey.MESSAGE_NEW.equals(event.getKey())) {
            this.addMessage(event.getContent());
        }
    }

    @Override
    public boolean persist(Message message) {
        return true;
    }

    @Override
    public boolean listensToMessageType(Message message) {
        return true;
    }

    @Override
    public boolean listensTo(GuiEventKey guiEventKey) {
        return MessageEventKey.MESSAGE_NEW.equals(guiEventKey) || MessageEventKey.MESSAGE_READ.equals(guiEventKey);
    }
}
