/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.message.inbox;

import nl.cloudfarming.client.message.api.MessageService;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JScrollPane;
import nl.cloudfarming.client.message.api.Message;
import org.jdesktop.swingx.ScrollableSizeHint;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;
import org.openide.explorer.ExplorerManager;
import org.openide.util.Lookup;

/**
 * Top component which displays something.
 */
//@ConvertAsProperties(dtd = "-//nl.cloudfarming.client.message.inbox//Messages//EN",
//autostore = false)
//@TopComponent.Description(preferredID = "MessagesTopComponent",
//iconBase = "nl/cloudfarming/client/icon/mail-message-new.png",
//persistenceType = TopComponent.PERSISTENCE_ALWAYS)
//@TopComponent.Registration(mode = "properties", openAtStartup = false)
//@ActionID(category = "Window", id = "nl.cloudfarming.client.message.inbox.MessagesTopComponent")
//@ActionReference(path = "Menu/Window/Application Output" /*, position = 333 */)
//@TopComponent.OpenActionRegistration(displayName = "#message.inbox.window.title",
//preferredID = "MessagesTopComponent")
public final class MessagesTopComponent extends TopComponent implements ExplorerManager.Provider, PropertyChangeListener {

    private ExplorerManager explorerManager;
//    private OutlineView view = new OutlineView();
    private final MessagesPanel messagesPanel = new MessagesPanel();
    private boolean initialized = false;
    private final JScrollPane scrollPane;

    private static final String NAME = NbBundle.getMessage(MessagesTopComponent.class, "message.inbox.window.title");
    private static final String TOOL_TIP = NbBundle.getMessage(MessagesTopComponent.class, "message.inbox.window.tooltip");
            
    public MessagesTopComponent() {
        setName(NAME);
        setToolTipText(TOOL_TIP);
        MessageService inbox = Lookup.getDefault().lookup(MessageService.class);
        explorerManager = inbox.getExplorerManager();
        associateLookup(inbox.getLookup());

        messagesPanel.setScrollableHeightHint(ScrollableSizeHint.NONE);
        messagesPanel.setScrollableWidthHint(ScrollableSizeHint.NONE);
        scrollPane = new JScrollPane(messagesPanel, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        add(scrollPane);
    }

    @Override
    public void componentOpened() {
        MessageService inbox = Lookup.getDefault().lookup(MessageService.class);
//        inbox.addMessagePropertyChangeListener(this);
        if (!initialized) {
            for (Message message : inbox.getAllMessages()) {
                messagesPanel.addMessage(message);
            }
            initialized = true;
        }
    }

    @Override
    public void componentClosed() {
        MessageService inbox = Lookup.getDefault().lookup(MessageService.class);
//        inbox.removeMessagePropertyChangeListener(this);        
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
    }

    @Override
    public ExplorerManager getExplorerManager() {
        return explorerManager;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if(MessageService.PROPERTY_ADDED.equals(evt.getPropertyName())){
            messagesPanel.addMessage((Message)evt.getNewValue());
        }
    }
}
